dag_cbor.decoding
=================

.. automodule:: dag_cbor.decoding

DecodeCallback
--------------

.. autoclass:: dag_cbor.decoding.DecodeCallback
    :show-inheritance:
    :members:

decode
------

.. autofunction:: dag_cbor.decoding.decode
